/*
 * add to pom.xml:
 * 
 * <dependency>
    <groupId>org.junit.jupiter</groupId>
    <artifactId>junit-jupiter-api</artifactId>
    <version>5.7.0</version>
    <scope>test</scope>
</dependency>


RUN TEST:
'mvn test'

 */

package object_detection;

import static org.junit.jupiter.api.Assertions.*;
import org.junit.jupiter.api.Test;
import java.util.List;

class ObjectDetectionTests {

    @Test
    void testPointCreation() {
        Point p = new Point(1.0f, 2.0f, 3.0f);
        assertEquals(1.0f, p.getX());
        assertEquals(2.0f, p.getY());
        assertEquals(3.0f, p.getZ());
    }

    @Test
    void testPointEquality() {
        Point p1 = new Point(1.0f, 2.0f, 3.0f);
        Point p2 = new Point(1.0f, 2.0f, 3.0f);
        assertTrue(Point.equals(p1, p2, 0.01f));
    }

    @Test
    void testAddPointToSet() {
        PointSet ps = new PointSet();
        ps.addPoint(new Point(1.0f, 2.0f, 3.0f));
        assertEquals(1, ps.getPoints().size());
    }

    @Test
    void testUpdateReps() {
        PointSet ps = new PointSet(new Point(1.0f, 2.0f, 3.0f), new Point(4.0f, 5.0f, 6.0f));
        ps.updateReps();
        assertNotNull(ps.getSetReps()[0]);
    }

    @Test
    void testObjectCreationAndComparison() {
        ObjectSet os = new ObjectSet();
        int obj1 = os.makeObject(new Point(0, 10, 0), new Point(0, 0, 0));
        int obj2 = os.makeObject(new Point(0, 10, 0), new Point(0, 0, 0));
        assertTrue(ObjectSet.compareObjects(obj1, obj2));
    }

    @Test
    void testCombineObjects() {
        ObjectSet os = new ObjectSet();
        int obj1 = os.makeObject(new Point(0, 10, 0), new Point(0, 0, 0));
        int obj2 = os.makeObject(new Point(10, 20, 0), new Point(10, 10, 0));
        os.combineObjects(obj1, obj2);
        assertEquals(1, os.objects.size());
    }

    @Test
    void testObjectDetector() {
        ObjectDetector.run();
        assertNotNull(ObjectDetector.os);
        assertEquals(1, ObjectDetector.os.objects.size());  // Assuming combining reduces size to 1
    }
}